@@ -54,29 +54,16 @@ class GRWidget(QWidget):
     def __init__(self, *args, **kwargs):
         super(GRWidget, self).__init__(*args, **kwargs)
 
-        try:
-            self.devicePixelRatioF()
-        except AttributeError:
-            try:
-                self.devicePixelRatio()
-            except AttributeError:
-                self.devicePixelRatio = lambda: 1
-            self.devicePixelRatioF = lambda: float(self.devicePixelRatio())
-
-        self.currentDevicePixelRatio = self.devicePixelRatioF()
-
         self._sizex, self._sizey = 1., 1.
         self._dwidth, self._dheight = self.width(), self.height()
-        self._mwidth = self._dwidth * 2.54 / self.physicalDpiX() / 100. / self.currentDevicePixelRatio
-        self._mheight = self._dheight * 2.54 / self.physicalDpiY() / 100. / self.currentDevicePixelRatio
+        self._mwidth = self._dwidth * 2.54 / self.physicalDpiX() / 100.
+        self._mheight = self._dheight * 2.54 / self.physicalDpiY() / 100.
         self._keepRatio = False
         self._bgColor = QtCore.Qt.white
         os.environ["GKS_WSTYPE"] = "381" # GKS Qt Plugin
         os.environ["GKS_DOUBLE_BUF"] = "True"
 
     def paintEvent(self, event):
-        if self.devicePixelRatioF() != self.currentDevicePixelRatio:
-            self.resizeEvent(None)
 
         self._painter = QPainter()
         self._painter.begin(self)
@@ -89,9 +76,8 @@ class GRWidget(QWidget):
 
     def resizeEvent(self, event):
         self._dwidth, self._dheight = self.width(), self.height()
-        self.currentDevicePixelRatio = self.devicePixelRatioF()
-        self._mwidth = self._dwidth * 2.54 / self.physicalDpiX() / 100. / self.currentDevicePixelRatio
-        self._mheight = self._dheight * 2.54 / self.physicalDpiY() / 100. / self.currentDevicePixelRatio
+        self._mwidth = self._dwidth * 2.54 / self.physicalDpiX() / 100.
+        self._mheight = self._dheight * 2.54 / self.physicalDpiY() / 100.
         if self._mwidth > self._mheight:
             self._sizex = 1.
             if self.keepRatio:
@@ -113,6 +99,10 @@ class GRWidget(QWidget):
                 self._sizex = 1.
             self._sizey = 1.
 
+    def screenChangedEvent(self, event):
+        gr.configurews()
+        self.update()
+
     def setBackground(self, qcolor):
         self._bgColor = qcolor
 
